summaryrefslogtreecommitdiffstats
path: root/win/tclWinInit.c
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2020-09-11 14:23:14 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2020-09-11 14:23:14 (GMT)
commit278837f261adb88e6a802f3ebaf63e232c12e77f (patch)
treeb6a9653503ead5496a456e1301cc2244c8fba4a0 /win/tclWinInit.c
parentd16f803f15be4e185b584faf662863362cfffe5c (diff)
downloadtcl-278837f261adb88e6a802f3ebaf63e232c12e77f.zip
tcl-278837f261adb88e6a802f3ebaf63e232c12e77f.tar.gz
tcl-278837f261adb88e6a802f3ebaf63e232c12e77f.tar.bz2
More usage for TclNewWideIntObjFromSize(), TCL_IO_FAILURE -> TCL_INDEX_NONE where appropriate
Diffstat (limited to 'win/tclWinInit.c')
-rw-r--r--win/tclWinInit.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/win/tclWinInit.c b/win/tclWinInit.c
index f6c9f83..4726bb3 100644
--- a/win/tclWinInit.c
+++ b/win/tclWinInit.c
@@ -614,7 +614,7 @@ TclpSetVariables(
*
* Results:
* The return value is the index in environ of an entry with the name
* "name", or TCL_IO_FAILURE if there is no such entry. The integer
* at *lengthPtr is filled in with the length of name (if a matching
* entry is found) or the length of the environ array (if no
* matching entry is found).
@@ -637,7 +637,7 @@ TclpFindVariable(
* entries in environ (for unsuccessful
* searches). */
{
- size_t i, length, result = TCL_IO_FAILURE;
+ size_t i, length, result = TCL_INDEX_NONE;
const WCHAR *env;
const char *p1, *p2;
char *envUpper, *nameUpper;
@@ -614,7 +614,7 @@ TclpSetVariables(
* Results:
* The return value is the index in environ of an entry with the name
- * "name", or TCL_IO_FAILURE if there is no such entry. The integer
+ * "name", or TCL_INDEX_NONE if there is no such entry. The integer
* at *lengthPtr is filled in with the length of name (if a matching
* entry is found) or the length of the environ array (if no